@@ -2,7 +2,7 @@
  * File name: Rk.h
  * Project: Redkite (A small GUI toolkit)
  *
- * Copyright (C) 2019 Iurie Nistor <http://geontime.com>
+ * Copyright (C) 2019 Iurie Nistor <http://iuriepage.wordpress.com>
  *
  * This file is part of Redkite.
  *
@@ -24,11 +24,12 @@
 #ifndef RK_GLOBAL_H
 #define RK_GLOBAL_H
 
-#define RK_VERSION 0x010001
+#define RK_VERSION 0x010300
 #define RK_MAJOR   0x01
-#define RK_MINOR   0x00
-#define RK_PATCH   0x01
+#define RK_MINOR   0x03
+#define RK_PATCH   0x00
 
+#include <utility>
 #include <memory>
 #include <vector>
 #include <string>
@@ -37,6 +38,12 @@
 #include <thread>
 #include <chrono>
 #include <functional>
+#include <unordered_map>
+#include <unordered_set>
+#include <mutex>
+#include <array>
+#include <iostream>
+#include <sstream>
 
 #define RK_UNUSED(expr) (void)expr
 
@@ -93,14 +100,6 @@ using rk_real = double;
 #endif // RK_SINGLE_PRECISION
 
 namespace Rk {
-        struct RkEnumClassHash {
-                template <typename T>
-                int operator()(T t) const
-                {
-                        return static_cast<int>(t);
-                }
-        };
-
         enum class Alignment : int {
                 AlignLeft   = 1,
                 AlignRight  = 2,
@@ -441,7 +440,7 @@ namespace Rk {
                 Object = 0,
                 Widget = 1
         };
-};
+}
 
 #define RK_ACT_ARGS(arg, ...) arg, ##__VA_ARGS__
 #define RK_ARG_TYPE(type, ...) type, ##__VA_ARGS__
@@ -483,4 +482,6 @@ namespace Rk {
 #define RK_DECLARE_IMAGE_RC(name) extern const unsigned char rk__ ## name ## _png[]
 #define RK_IMAGE_RC(name) rk__ ## name ## _png
 
+using RkString = std::string;
+
 #endif // RK_GLOBAL_H
